@@ -12,12 +12,17 @@ test_that("Check monotonicity_test works for valid inputs", {
                                         ncores = 1)
 
   # Check all types match
+  expect_s3_class(res, "monotonicity_result")
   expect_equal(boot_num, length(res$dist))
   expect_type(res$p, "double")
   expect_type(res$stat, "double")
   expect_true(is.vector(res$dist))
   expect_true(is.vector(res$interval))
   expect_s3_class(res$plot, "ggplot")
+
+  # Making sure s3 methods print
+  expect_output(print(res))
+  expect_output(summary(res))
 })
 
 test_that("Check if monotonicity_test input validation works", {
